@@ -4,6 +4,7 @@ Description: Omit
 LastEditors: Rustle Karl
 LastEditTime: 2022.02.02 18:14
 """
+import contextlib
 import os
 import shutil
 
@@ -35,26 +36,29 @@ def clean():
     build_dirs = {
         "cmake-build-debug",  # Clion cmake build
         "cmake-build-release",  # Makefile cmake build
+        "node_modules",
     }
 
     for root, dirs, files in os.walk("."):
         for f in files:
-            if f.find("example") != -1 or f in {"ToolkitPy_logo.png"}:
+            if f.lower().find("example") != -1 or f in {"ToolkitPy_logo.png"}:
                 f = os.path.join(root, f)
                 click.echo(f"clean {f}")
                 os.unlink(f)
 
         for d in dirs:
-            if d.find("example") != -1:
+            if d.lower().find("example") != -1:
                 d = os.path.join(root, d)
                 click.echo(f"clean {d}")
-                os.rmdir(d)
+                with contextlib.suppress(OSError):
+                    os.rmdir(d)
 
-            elif d in build_dirs:
-                d = os.path.join(root, d)
-                click.echo(f"clean {d}")
-                shutil.rmtree(d)
-                os.mkdir(d)
+            else:
+                for build_dir in build_dirs:
+                    if d.lower().find(build_dir) != -1:
+                        d = os.path.join(root, d)
+                        click.echo(f"clean {d}")
+                        shutil.rmtree(d)
 
 
 @command_cps.command(
@@ -77,8 +81,15 @@ def python():
     type=click.Choice(GoCombinations),
     help="Combination of frameworks.",
 )
-def golang(combination):
-    _golang(combination)
+@click.option(
+    "--entity",
+    "-e",
+    type=str,
+    default="",
+    help="New entity instance.",
+)
+def golang(combination, entity):
+    _golang(combination, entity)
 
 
 @command_cps.command(help="Create notes project scaffold.")
