@@ -8,6 +8,10 @@ import (
 	"{{GOLANG_MODULE}}/internal/query"
 )
 
+func init() {
+	AddRouteRegistrar(GetAppDescription)
+}
+
 func GetAppDescription(router *echo.Group) {
 	router.GET("/app/description", func(c echo.Context) error {
 		return SendJSON(c, query.GetAppDescription())
