@@ -6,6 +6,7 @@ import (
 	"fmt"
 	"time"
 
+	"github.com/jinzhu/copier"
 	"gorm.io/gorm"
 
 	"{{GOLANG_MODULE}}/internal/acl"
@@ -23,15 +24,15 @@ type User struct {
 	Username string `gorm:"column:username;size:128;" json:"username"`
 	Password string `gorm:"-" json:"-"`
 
-	Role acl.Role `gorm:"size:32;default:default;" json:"role"`
+	Role acl.Role `gorm:"size:32;default:default;" json:"-"`
 
 	Disabled bool `json:"disabled"`
 
 	LoginAttempts int       `json:"-" yaml:"-"` // 登录密码尝试次数
 	LoginAt       time.Time `json:"-"`          // 最近一次登录时间
 
-	CreatedAt time.Time      `json:"created_at"`
-	UpdatedAt time.Time      `json:"updated_at"`
+	CreatedAt time.Time      `json:"-"`
+	UpdatedAt time.Time      `json:"-"`
 	DeletedAt gorm.DeletedAt `json:"-"`
 }
 
@@ -78,6 +79,14 @@ func CreateDefaultUsers() {
 	}
 }
 
+func (m *User) CopyFrom(src interface{}) error {
+	return copier.Copy(m, src)
+}
+
+func (m *User) CopyTo(dst interface{}) error {
+	return copier.Copy(dst, m)
+}
+
 // Create new entity in the database.
 func (m *User) Create() error {
 	return Db().Create(m).Error
